@@ -28,7 +28,7 @@ from tastypie.validation import Validation
 
 from oppia.api.serializers import PrettyJSONSerializer, CourseJSONSerializer, TagJSONSerializer, UserJSONSerializer
 from oppia.models import Activity, Section, Tracker, Course, CourseDownload, Media, Schedule, ActivitySchedule, Cohort, Tag, CourseTag
-from oppia.models import Points, Award, Badge
+from oppia.models import Points, Award, Badge, UserProfile
 from oppia.profile.forms import RegisterForm
 from oppia.signals import course_downloaded
  
@@ -54,6 +54,7 @@ class UserResource(ModelResource):
     points = fields.IntegerField(readonly=True)
     badges = fields.IntegerField(readonly=True)
     scoring = fields.BooleanField(readonly=True)
+    badging = fields.BooleanField(readonly=True)
     metadata = fields.CharField(readonly=True)
     
     class Meta:
@@ -103,6 +104,9 @@ class UserResource(ModelResource):
     def dehydrate_scoring(self,bundle):
         return settings.OPPIA_POINTS_ENABLED
     
+    def dehydrate_badging(self,bundle):
+        return settings.OPPIA_BADGES_ENABLED
+    
     def dehydrate_metadata(self,bundle):
         return settings.OPPIA_METADATA
 
@@ -113,6 +117,7 @@ class RegisterResource(ModelResource):
     points = fields.IntegerField(readonly=True)
     badges = fields.IntegerField(readonly=True)
     scoring = fields.BooleanField(readonly=True)
+    badging = fields.BooleanField(readonly=True)
     metadata = fields.CharField(readonly=True)
     
     class Meta:
@@ -157,6 +162,11 @@ class RegisterResource(ModelResource):
             bundle.obj.first_name = first_name
             bundle.obj.last_name = last_name
             bundle.obj.save()
+            
+            user_profile = UserProfile()
+            user_profile.user = bundle.obj
+            user_profile.save()
+            
             u = authenticate(username=username, password=password)
             if u is not None:
                 if u.is_active:
@@ -182,6 +192,9 @@ class RegisterResource(ModelResource):
     def dehydrate_scoring(self,bundle):
         return settings.OPPIA_POINTS_ENABLED
     
+    def dehydrate_badging(self,bundle):
+        return settings.OPPIA_BADGES_ENABLED
+    
     def dehydrate_metadata(self,bundle):
         return settings.OPPIA_METADATA
     
@@ -193,6 +206,7 @@ class TrackerResource(ModelResource):
     points = fields.IntegerField(readonly=True)
     badges = fields.IntegerField(readonly=True)
     scoring = fields.BooleanField(readonly=True)
+    badging = fields.BooleanField(readonly=True)
     metadata = fields.CharField(readonly=True)
     
     class Meta:
@@ -204,7 +218,7 @@ class TrackerResource(ModelResource):
         authorization = Authorization() 
         serializer = PrettyJSONSerializer()
         always_return_data =  True
-        fields = ['points','digest','data','tracker_date','badges','course','completed','scoring','metadata']
+        fields = ['points','digest','data','tracker_date','badges','course','completed','scoring','metadata','badging']
               
     def hydrate(self, bundle, request=None):
         # remove any id if this is submitted - otherwise it may overwrite existing tracker item
@@ -259,7 +273,7 @@ class TrackerResource(ModelResource):
         try:
             json_data = json.loads(bundle.data['data'])
             if json_data['uuid']:
-                bundle.obj.time_taken = json_data['uuid']
+                bundle.obj.uuid = json_data['uuid']
         except:
             pass
         
@@ -276,6 +290,9 @@ class TrackerResource(ModelResource):
     def dehydrate_scoring(self,bundle):
         return settings.OPPIA_POINTS_ENABLED
     
+    def dehydrate_badging(self,bundle):
+        return settings.OPPIA_BADGES_ENABLED
+    
     def dehydrate_metadata(self,bundle):
         return settings.OPPIA_METADATA
     
@@ -292,6 +309,7 @@ class TrackerResource(ModelResource):
         response_data = {'points': self.dehydrate_points(bundle),
                          'badges':self.dehydrate_badges(bundle),
                          'scoring':self.dehydrate_scoring(bundle),
+                         'badging':self.dehydrate_badging(bundle),
                          'metadata':self.dehydrate_metadata(bundle)}
         response = HttpResponse(content=json.dumps(response_data),content_type="application/json; charset=utf-8")
         return response
@@ -513,7 +531,7 @@ class PointsResource(ModelResource):
         always_return_data = True
         
     def get_object_list(self, request):
-        return super(PointsResource, self).get_object_list(request).filter(user = request.user)
+        return super(PointsResource, self).get_object_list(request).filter(user = request.user)[:100]
     
     def dehydrate(self, bundle):
         bundle.data['date'] = bundle.data['date'].strftime("%Y-%m-%d %H:%M:%S")
@@ -533,6 +551,7 @@ class BadgesResource(ModelResource):
 class AwardsResource(ModelResource):
     badge = fields.ForeignKey(BadgesResource, 'badge', full=True, null=True)
     badge_icon = fields.CharField(attribute='_get_badge', readonly=True)
+    
     class Meta:
         queryset = Award.objects.all().order_by('-award_date')
         allowed_methods = ['get']
@@ -554,6 +573,6 @@ class AwardsResource(ModelResource):
         url = prefix + bundle.request.META['SERVER_NAME'] + settings.MEDIA_URL + bundle.data['badge_icon']
         return url
     
-
-    
-    
+    def dehydrate(self, bundle):
+        bundle.data['award_date'] = bundle.data['award_date'].strftime("%Y-%m-%d %H:%M:%S")
+        return bundle
