@@ -1,11 +1,12 @@
 # oppia/models.py
-import json
 import datetime
+import json
 
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.db import models
 from django.db.models import Max, Sum, Q
+
 from django.utils.translation import ugettext_lazy as _
 
 from tastypie.models import create_api_key
@@ -14,6 +15,11 @@ from xml.dom.minidom import *
 
 models.signals.post_save.connect(create_api_key, sender=User)
 
+class UserProfile (models.Model):
+    user = models.OneToOneField(User)
+    about = models.TextField(blank=True, null=True, default=None)
+    job_title = models.TextField(blank=True, null=True, default=None)
+    organisation = models.TextField(blank=True, null=True, default=None)
 
 class Course(models.Model):
     user = models.ForeignKey(User)
@@ -267,12 +273,39 @@ class Tracker(models.Model):
         for m in media:
             return "media"
         return None
-        
-    def get_activity_title(self):
+     
+    def get_media_title(self):
         media = Media.objects.filter(digest=self.digest)
         for m in media:
             return m.filename
         return None
+           
+    def get_activity_title(self, lang='en'):
+        media = Media.objects.filter(digest=self.digest)
+        for m in media:
+            return m.filename
+        try:
+            titles = json.loads(self.activity_title)
+            if lang in titles:
+                return titles[lang]
+            else:
+                for l in titles:
+                    return titles[l]
+        except:
+            pass
+        return self.activity_title
+    
+    def get_section_title(self, lang='en'):
+        try:
+            titles = json.loads(self.section_title)
+            if lang in titles:
+                return titles[lang]
+            else:
+                for l in titles:
+                    return titles[l]
+        except:
+            pass
+        return self.section_title
     
     def activity_exists(self):
         activities = Activity.objects.filter(digest=self.digest).count()
