@@ -4,6 +4,7 @@ import json
 import shutil
 import os
 import oppia
+import tablib
 
 from django import forms
 from django.conf import settings
@@ -143,8 +144,7 @@ def recent_activity_detail(request,id):
     # If page request (9999) is out of range, deliver last page of results.
     try:
         tracks = paginator.page(page)
-        for t in tracks:
-            t.title = t.get_activity_title()   
+        for t in tracks:  
             t.data_obj = []
             try:
                 data_dict = json.loads(t.data)
@@ -160,6 +160,25 @@ def recent_activity_detail(request,id):
     return render_to_response('oppia/course/activity-detail.html',{'course': course,'page':tracks,}, context_instance=RequestContext(request))
 
 
+def export_tracker_detail(request,id):
+    course = check_owner(request,id)
+    
+    headers = ('Date', 'UserId', 'Type', 'Activity Title', 'Section Title', 'Time Taken', 'IP Address', 'User Agent', 'Language')
+    data = []
+    data = tablib.Dataset(*data, headers=headers)
+    trackers = Tracker.objects.filter(course=course).order_by('-tracker_date')
+    for t in trackers:
+        data_dict = json.loads(t.data)
+        if 'lang' in data_dict:
+            lang = data_dict['lang']
+        else:
+            lang = ""
+        data.append((t.tracker_date.strftime('%Y-%m-%d %H:%M:%S'), t.user.id, t.type, t.get_activity_title(), t.get_section_title(), t.time_taken, t.ip, t.agent, lang))
+    response = HttpResponse(data.xls, content_type='application/vnd.ms-excel;charset=utf-8')
+    response['Content-Disposition'] = "attachment; filename=export.xls"
+
+    return response
+    
 def schedule(request,course_id):
     course = check_owner(request,course_id)    
     schedules = Schedule.objects.filter(course=course)
